changeset 96997:8e0048b7af16

(Fx_select_font): Reverse sense of second arg.
author Jason Rumney <jasonr@gnu.org>
date Fri, 25 Jul 2008 00:36:45 +0000
parents 3035988dd0b3
children 2d3110c3f3dd
files src/ChangeLog src/w32font.c
diffstat 2 files changed, 9 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/src/ChangeLog	Thu Jul 24 23:46:50 2008 +0000
+++ b/src/ChangeLog	Fri Jul 25 00:36:45 2008 +0000
@@ -1,3 +1,7 @@
+2008-07-25  Jason Rumney  <jasonr@gnu.org>
+
+        * w32font.c (Fx_select_font): Reverse sense of second arg.
+
 2008-07-24  Stefan Monnier  <monnier@iro.umontreal.ca>
 
 	* syntax.c (struct lisp_parse_state, char_quoted, inc_bytepos)
--- a/src/w32font.c	Thu Jul 24 23:46:50 2008 +0000
+++ b/src/w32font.c	Fri Jul 25 00:36:45 2008 +0000
@@ -2328,10 +2328,10 @@
 Return fontconfig style font string corresponding to the selection.
 
 If FRAME is omitted or nil, it defaults to the selected frame.
-If INCLUDE-PROPORTIONAL is non-nil, include proportional fonts
+If EXCLUDE-PROPORTIONAL is non-nil, exclude proportional fonts
 in the font selection dialog. */)
-  (frame, include_proportional)
-     Lisp_Object frame, include_proportional;
+  (frame, exclude_proportional)
+     Lisp_Object frame, exclude_proportional;
 {
   FRAME_PTR f = check_x_frame (frame);
   CHOOSEFONT cf;
@@ -2348,9 +2348,9 @@
   cf.hwndOwner = FRAME_W32_WINDOW (f);
   cf.Flags = CF_FORCEFONTEXIST | CF_SCREENFONTS | CF_NOVERTFONTS;
 
   /* Unless include_proportional is non-nil, limit the selection to
      monospaced fonts.  */
-  if (NILP (include_proportional))
+  if (!NILP (exclude_proportional))
     cf.Flags |= CF_FIXEDPITCHONLY;
 
   cf.lpLogFont = &lf;
@@ -2348,9 +2348,9 @@
   cf.Flags = CF_FORCEFONTEXIST | CF_SCREENFONTS | CF_NOVERTFONTS;
 
-  /* Unless include_proportional is non-nil, limit the selection to
+  /* If exclude_proportional is non-nil, limit the selection to
      monospaced fonts.  */